yt.utilities.chemical\_formulas module
======================================

.. automodule:: yt.utilities.chemical_formulas
   :members:
   :undoc-members:
   :inherited-members:
   :show-inheritance:
